@@ -1,4 +1,3 @@
-# Lint as: python3
 # Copyright 2020 DeepMind Technologies Limited. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -41,6 +40,10 @@ TLeavesEqCmpFn = Callable[[TLeaf, TLeaf], bool]
 TLeavesEqCmpErrorFn = Callable[[TLeaf, TLeaf], str]
 
 
+def _format_tree_path(path: Sequence[Any]) -> str:
+  return "/".join(str(p) for p in path)
+
+
 def _num_devices_available(devtype: str, backend: Optional[str] = None) -> int:
   """Returns the number of available device of the given type."""
   devtype = devtype.lower()
@@ -68,8 +71,9 @@ def _is_traceable(fn):
 
   tokens = (
       "_python_jit.",  # PyJIT  in Python ver. < 3.7
-      "_cpp_jit.",  # CppJIT in Python ver. < 3.7
+      "_cpp_jit.",  # CppJIT in Python ver. < 3.7 (deprecated)
       ".reraise_with_filtered_traceback",  # JIT    in Python ver. >= 3.7
+      "CompiledFunction",  # C++ JIT in jaxlib 0.1.66 or newer.
       "pmap.",  # pmap
       "vmap.",  # vmap
   )
@@ -91,6 +95,12 @@ def _is_traceable(fn):
       if "api_boundary" in fn_globals:
         # api_boundary is a JAX wrapper for traced functions.
         return True
+
+      try:
+        if isinstance(fn_, jax.lib.xla_extension.jax_jit.CompiledFunction):
+          return True
+      except AttributeError:
+        pass
     else:
       break
 
@@ -103,7 +113,7 @@ def _assert_leaves_all_eq_comparator(
     error_msg_fn: Callable[[TLeaf, TLeaf, str, int, int],
                            str], path: Sequence[Any], *leaves: Sequence[TLeaf]):
   """Asserts all leaves are equal using custom comparator."""
-  path_str = "/".join(str(p) for p in path)
+  path_str = _format_tree_path(path)
   for i in range(1, len(leaves)):
     if not equality_comparator(leaves[0], leaves[i]):
       raise AssertionError(error_msg_fn(leaves[0], leaves[i], path_str, 0, i))
@@ -610,8 +620,7 @@ def assert_tree_no_nones(tree: ArrayTree):
 
   def _assert_fn(path, leaf):
     if leaf is None:
-      formatted_path = "/".join(str(p) for p in path)
-      raise AssertionError(f"`None` detected at '{formatted_path}'.")
+      raise AssertionError(f"`None` detected at '{_format_tree_path(path)}'.")
 
   dm_tree.map_structure_with_path(_assert_fn, tree)
 
@@ -640,7 +649,7 @@ def assert_tree_shape_prefix(tree: ArrayTree,
     prefix = leaf.shape[:len(shape_prefix)]
     if prefix != shape_prefix:
       raise AssertionError(
-          f"Tree leaf '{'/'.join(path)}' has a shape prefix "
+          f"Tree leaf '{_format_tree_path(path)}' has a shape prefix "
           f"diffent from expected: {prefix} != {shape_prefix}.")
 
   dm_tree.map_structure_with_path(_assert_fn, tree)
@@ -864,3 +873,9 @@ def if_args_not_none(fn, *args, **kwargs):
     found_none = found_none or (x is None)
   if not found_none:
     fn(*args, **kwargs)
+
+
+def assert_is_divisible(numerator: int, denominator: int):
+  """Assert that the numerator is divisible exactly by the denominator."""
+  if numerator % denominator != 0:
+    raise AssertionError(f"{numerator} is not divisible by {denominator}")
