@@ -1,4 +1,3 @@
-# Lint as: python3
 # Copyright 2020 DeepMind Technologies Limited. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,6 +15,7 @@
 """Tests for `asserts.py`."""
 
 import functools
+
 from absl.testing import absltest
 from absl.testing import parameterized
 from chex._src import asserts
@@ -907,6 +907,16 @@ class EqualAssertionsTest(parameterized.TestCase):
       asserts.assert_equal(first, second)
 
 
+class IsDivisibleTest(parameterized.TestCase):
+
+  def test_assert_is_divisible(self):
+    asserts.assert_is_divisible(6, 3)
+
+  def test_assert_is_divisible_fail(self):
+    with self.assertRaises(AssertionError):
+      asserts.assert_is_divisible(7, 3)
+
+
 if __name__ == '__main__':
   jax.config.update('jax_numpy_rank_promotion', 'raise')
   absltest.main()
