@@ -1,4 +1,3 @@
-# Lint as: python3
 # Copyright 2020 DeepMind Technologies Limited. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -342,7 +341,8 @@ def _with_jit(fn,
               **unused_kwargs):
   """Variant that applies `jax.jit` to fn."""
 
-  return jax.jit(fn, static_argnums, device, backend)
+  return jax.jit(fn, static_argnums=static_argnums, device=device,
+                 backend=backend)
 
 
 @toolz.curry
